<?php
/**
 * Validation Functions
 *
 * This contains validation functions, these are NOT required but highly suggested
 * These validation/sanitisation will help stop attackers injecting code they may not completely stop it.
 *
 **/


/**
 * Validate the email address input, currently only uses the built in validator but this function allow for checks to be added.
 *
 * This function returns TRUE if it passes validation and FALSE if it fails.
 **/
// Email Validation, uses the default PHP function plus some added extras for more security.
function validate_email($email){
  if(($email == "")||(!isset($email))){
    $bool = FALSE;
  }else{
      if(!filter_var($email, FILTER_VALIDATE_EMAIL)){
            $bool = FALSE;
      }else{
            $bool = TRUE;
      }
  }
  return $bool;
}

/**
 * Checks to see if the given number is odd or even
 *
 * This function returns TRUE if it passes validation and FALSE if it fails.
 **/
function is_odd($number) { return($number & 1); }


/**
 * Changes the priority digit to human readable and also has an unknown option for anything weird
 *
 **/
function priority_change($status){

	if(strtolower($status) == 0){
		$code = "Low";
	}elseif(strtolower($status) == 1){
		$code = "Normal";
	}elseif(strtolower($status) == 2){
		$code = "High";
	}elseif(strtolower($status) == 3){
		$code = "Urgent";
	}else{
		logger("Debug","priority_change","Unknown option input: ".$status);
		$code = "Unknown";
	}
  return $code;
}

function file_link_start($status){
	if((strtolower($status) == "null")||(strtolower($status) == NULL)){
		$code = "";
	}else{
		$code = "<a href=\"files/".$status."\" target=\"_blank\">";
	}
  return $code;
}
function file_link_text($status){
	if((strtolower($status) == "null")||(strtolower($status) == NULL)){
		$code = "";
	}else{
		$code = "Attachments&hellip;";
	}
  return $code;
}
function file_link_end($status){
	if((strtolower($status) == "null")||(strtolower($status) == NULL)){
		$code = "";
	}else{
		$code = "</a>";
	}
  return $code;
}

function status_text($status){
	if(strtolower($status) == "2"){
		$code = "Closed";
	}elseif(strtolower($status) == "1"){
		$code = "Pending";
	}elseif(strtolower($status) == "0"){
		$code = "Open";
	}else{
		logger("Debug","status_text","Unknown option input: ".$status);
		$code = "Unknown";
	}
  return $code;
}

/**
 * Changes the user type from numeric to text and keeps it text if already text
 *
 **/
function user_type_change($type){
	if(($type == 1)||($type == "1")||(strtoupper($type) == "U")){
		$result = "U";
	}elseif(($type == 2)||($type == "2")||(strtoupper($type) == "S")){
		$result = "S";
	}else{
		logger("Debug","user_type_change","Unknown option input: ".$type);
		die("Debug Error");
	}
  return $result;
}

/**
 * Generate an ExpressFind™ code
 *
 **/
function make_ef(){
  $letters = array("A","B","C","D","E","F","G","H","I","J","K","L","M","N","O","P","Q","R","S","T","U","V","W","X","Y","Z");
  $numbers = array("0","1","2","3","4","5","6","7","8","9");
  $letter_max = count($letters);
  $letter_max-1;
  $num_max = count($numbers);
  $num_max-1;
  $code = "";
  $i=0;
	do{
	$num_or_letter = rand(0,1);
		if($num_or_letter == 0){
			$num_rand = rand(0,$num_max);
			$code = $code.$numbers[$num_rand];
		}else{
			$letter_rand = rand(0,$letter_max);
			$up_or_low = rand(0,1);
			if($up_or_low == 0){
				$code = $code.strtolower($letters[$letter_rand]);
			}else{
				$code = $code.$letters[$letter_rand];
			}
		}
	$i++;
	}while($i != 12);
	$code = $code;
return $code;
}


/**
 * Deletes the filename given from the server.
 *
 * This function returns TRUE if it passes validation and FALSE if it fails.
 **/
function delete_file($filename){
	$deleted = unlink("files/".$filename);
  return $deleted;
}
?>